- **TRISTIS** (<u>magna</u>, vestibulum, type!, convallis?, ipsum?, pulvinar?, audis?, _#magna via_mollis?_, _#magna via_vitae?_, tempor?, fugit?)
  - Le champ _magna_ constitue la clé primaire de la table. C'était déjà un identifiant de l'entité _TRISTIS_.
  - Le champ _vestibulum_ était déjà un simple attribut de l'entité _TRISTIS_.
  - Un discriminateur à saisie obligatoire _type_ est ajouté pour indiquer la nature de la spécialisation. Jamais vide, du fait de la contrainte de totalité.
  - Le champ à saisie facultative _convallis_ a migré à partir de l'entité-fille _SODALES_ (supprimée).
  - Le champ à saisie facultative _ipsum_ a migré à partir de l'entité-fille _SODALES_ (supprimée).
  - Le champ à saisie facultative _pulvinar_ a migré à partir de l'entité-fille _NEC_ (supprimée).
  - Le champ à saisie facultative _audis_ a migré à partir de l'entité-fille _NEC_ (supprimée).
  - Le champ à saisie facultative _magna via_mollis_ est une clé étrangère. Il a migré à partir de l'entité-fille _NEC_ (supprimée) dans laquelle il avait déjà migré à partir de l'entité _TRISTIS_.
  - Le champ à saisie facultative _magna via_vitae_ est une clé étrangère. Il a migré à partir de l'entité-fille _NEC_ (supprimée) dans laquelle il avait déjà migré à partir de l'entité _TRISTIS_.
  - Le champ à saisie facultative _tempor_ a migré à partir de l'entité-fille _LACUS_ (supprimée).
  - Le champ à saisie facultative _fugit_ a migré à partir de l'entité-fille _LACUS_ (supprimée).

- **ULTRICES** (<u>_#magna sodales_</u>, <u>_#magna lacus_</u>)
  - Les champs _magna sodales_ et _magna lacus_ constituent la clé primaire de la table. Ce sont des clés étrangères qui ont migré directement à partir de l'entité _TRISTIS_.
